/******************************************************************************************************/
/*  Program: EXECUTE PROC S3 GET Files Macro Program.sas                                              */
/*                                                                                                    */
/*  Author: Michael A. Raithel, Westat                                                                */
/*                                                                                                    */
/*  Created: 12/16/2021                                                                               */
/*                                                                                                    */
/*  Purpose: This is the driver program for the PROC S3 GET Files Macro program that reads a flat     */
/*           file with the names of objects in an S3 bucket that are to be downloaded to a network    */
/*           drive. That program builds a PROC S3 "GET" statement for each object and executes PROC   */
/*           S3 to download the objects to the specified network directory.                           */
/*                                                                                                    */
/*  Parameters: Users must specify the following six parameters:                                      */
/*                                                                                                    */
/*             KEYID    - The access key ID for the S3 service                                        */
/*             REGION   - The region name for the S3 service                                          */
/*             SECRET   - The secret access key for the S3 service                                    */
/*             BUCKET   - The name of the AWS bucket folder the objects reside in                     */
/*             OUTDIR   - The full path name of the directory where the objects are to be downloaded  */
/*             FILELIST - The full path name of the flat file containing the names of the objects to  */
/*                        be downloaded                                                               */ 
/*                        NOTE: The program is expecting one object name per line within the flat file*/
/*                                                                                                    */
/*  Outputs: This program downloads the objects in the flat file specified by the FILELIST parameter  */
/*           to the directory specified by the OUTDIR parameter.                                      */
/*                                                                                                    */
/*           It also produces a PDF report file in the OUTDIR directory with up to three reports:     */
/*               1. Objects Successfully Dowloaded from S3                                            */
/*               2. Objects Listed In the Input File That Were NOT Downloaded from S3                 */
/*               3. Objects Existing in the Target Directory that Were Not in the Input List File     */
/*                                                                                                    */
/*           The name of the report file is:                                                          */
/*                                                                                                    */
/*               S3 File Transfer Report For Files Listed in -- <INPUTFILENAME>.pdf                   */
/*                                                                                                    */
/*  Change Log:                                                                                       */
/*                                                                                                    */
/******************************************************************************************************/

/* %INCLUDE the PROC S3 GET Files Macro Program */
%INCLUDE "<<Put Your Program Directory Here>>\PROC S3 GET Files Macro Program.sas";

/* Execute the PROC S3 GET Files Macro Program */
%GETS3FIL(KEYID=,
		  REGION=,
		  SECRET=,
		  BUCKET=,
		  OUTDIR=,
		  FILELIST=);




